@@ -9,13 +9,49 @@ use Scalar::Util qw/blessed reftype/;
 use Exporter 'import';
 our @EXPORT_OK = qw/ifdef $ifdef/;
 
+
+our $VERSION = '0.07';
+
+
+sub ifdef(&$) {
+    my ($block, $scalar) = @_;
+
+    return $scalar if not defined $scalar;
+    return $block->($scalar) for $scalar;
+}
+
+
+our $ifdef = sub {
+    my $obj = shift;
+    my ($method, @args) = @_;
+
+    return undef if not defined $obj;
+
+    return $obj->$method(@args)   if blessed $obj or reftype $method eq 'CODE';
+    return $obj->[$method]        if reftype $obj eq 'ARRAY';
+    return $obj->{$method}        if reftype $obj eq 'HASH';
+    return $obj->($method, @args) if reftype $obj eq 'CODE';
+
+    die "Can't getdef on " . reftype $obj;
+};
+
+
+
+1; # End of Scalar::IfDefined
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Scalar::IfDefined - Apply block to scalar depending on if it's defined.
+Scalar::IfDefined
 
-=cut
+=head1 VERSION
 
-our $VERSION = '0.06';
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -46,6 +82,10 @@ our $VERSION = '0.06';
             ==> ifdef { $_ + 1 }
     );            # ---> 3
 
+=head1 NAME
+
+Scalar::IfDefined - Apply block to scalar depending on if it's defined.
+
 =head1 EXPORT
 
 =over 4
@@ -68,15 +108,6 @@ straight away.
 If the scalar value is defined, then the block is evaluated with $_ as
 the value passed in, and the result of the block is returned.
 
-=cut
-
-sub ifdef(&$) {
-    my ($block, $scalar) = @_;
-
-    return $scalar if not defined $scalar;
-    return $block->($scalar) for $scalar;
-}
-
 =head2 $ifdef
 
 Used to dereference a possibly-undef scalar.
@@ -115,23 +146,6 @@ Right Thing if not.
     # those is undef
     $hashref->$ifdef('object')->$ifdef('method_name');
 
-=cut
-
-our $ifdef = sub {
-    my $obj = shift;
-    my ($method, @args) = @_;
-
-    return undef if not defined $obj;
-
-    return $obj->$method(@args)   if blessed $obj or reftype $method eq 'CODE';
-    return $obj->[$method]        if reftype $obj eq 'ARRAY';
-    return $obj->{$method}        if reftype $obj eq 'HASH';
-    return $obj->($method, @args) if reftype $obj eq 'CODE';
-
-    die "Can't getdef on " . reftype $obj;
-};
-
-
 =head1 AUTHOR
 
 Nick Booker, C<< <NMBooker at gmail.com> >>
@@ -140,7 +154,6 @@ Nick Booker, C<< <NMBooker at gmail.com> >>
 
 L<https://github.com/nmbooker/p5-Scalar-IfDefined/issues>
 
-
 =head1 ACKNOWLEDGEMENTS
 
 =head2 Alastair McGowan-Douglas (ALTREUS)
@@ -157,7 +170,15 @@ by the Free Software Foundation; or the Artistic License.
 
 See http://dev.perl.org/licenses/ for more information.
 
+=head1 AUTHOR
+
+Nick Booker <NMBooker@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Nick Booker.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1; # End of Scalar::IfDefined
